@@ -167,7 +167,7 @@ fn update_information_recursively(
             && file.name != "."
             && file.name != ".."
         {
-            match file.to_dir() {
+            match file.read_dir() {
                 Ok(dir) => {
                     let files: Vec<File<'_>> = dir
                         .files(dot_filter, git, git_ignoring, false, false)
@@ -185,7 +185,7 @@ fn update_information_recursively(
                 }
                 Err(e) => trace!("Unable to access directory {}: {}", file.name, e),
             }
-        };
+        }
     }
 }
 
@@ -203,7 +203,7 @@ impl Extremes {
                     range.max = value;
                 } else if value < range.min {
                     range.min = value;
-                };
+                }
             }
             (Some(value), rel) => {
                 let _ = rel.insert({
@@ -214,7 +214,7 @@ impl Extremes {
                 });
             }
             _ => (),
-        };
+        }
     }
 }
 
